module.exports = defineTest({
	description: 'tracks assigments nested in expressions that are included for other reasons'
});
